package eu.dnetlib.dnetrolemanagement.config.security;

import eu.dnetlib.dnetrolemanagement.config.properties.RedisProperties;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.redis.connection.lettuce.LettuceConnectionFactory;
import org.springframework.session.data.redis.config.annotation.web.http.EnableRedisHttpSession;
import org.springframework.session.web.http.CookieSerializer;
import org.springframework.session.web.http.DefaultCookieSerializer;

@EnableRedisHttpSession
@Configuration
public class RedisConfig {

    private static final Logger logger = Logger.getLogger(RedisConfig.class);
    private RedisProperties redisProperties;

    @Value("${webbapp.front.domain:openaire.eu}")
    private String domain;

    @Autowired
    public RedisConfig(RedisProperties redisProperties) {
        this.redisProperties = redisProperties;
    }

    @Bean
    public LettuceConnectionFactory connectionFactory() {
        logger.info(String.format("Redis connection listens to %s:%s ", redisProperties.getHost(), redisProperties.getPort()));
        LettuceConnectionFactory factory = new LettuceConnectionFactory(redisProperties.getHost(), Integer.parseInt(redisProperties.getPort()));
        if (redisProperties.getPassword() != null) factory.setPassword(redisProperties.getPassword());
        return factory;
    }

    @Bean
    public CookieSerializer cookieSerializer() {
        System.out.println("Cookie Serializer: Domain is " + domain);
        DefaultCookieSerializer serializer = new DefaultCookieSerializer();
        serializer.setCookieName("openAIRESession"); // <1>
        serializer.setCookiePath("/"); // <2>
        serializer.setDomainNamePattern("^.+?\\.(\\w+\\.[a-z]+)$");
        return serializer;
    }
}